﻿using SqlSugar;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Repository;
using Hotline.Orders;
using Hotline.Share.Enums.Snapshot;

namespace Hotline.Snapshot;

/// <summary>
/// 网格员红包审核
/// 先生成审核, 再生成红包发放记录
/// </summary>
[Description("网格员红包审核")]
public class RedPackGuiderAudit : CreationSoftDeleteEntity
{
    /// <summary>
    /// 关联工单编号
    /// <inheritdoc cref="Order"/>表的Id字段
    /// </summary>    
    [SugarColumn(ColumnDescription = "关联工单编号")]
    public string OrderId { get; set; }

    /// <summary>
    /// 领取手机号码
    /// </summary>
    [SugarColumn(ColumnDescription = "领取红包手机号码")]
    public string? PhoneNumber { get; set; }

    /// <summary>
    /// 一级审核状态
    /// </summary>
    [SugarColumn(ColumnDescription = "一级审核状态")]
    public ERedPackAuditStatus LevelOneStatus { get; set; }

    /// <summary>
    /// 二级审核状态
    /// </summary>
    [SugarColumn(ColumnDescription = "二级审核状态")]
    public ERedPackAuditStatus? LevelTwoStatus { get; set; }

    /// <summary>
    /// 一级审批时间
    /// </summary>
    [SugarColumn(ColumnDescription = "审批时间")]
    public DateTime? LevelOneAuditTime { get; set; }

    /// <summary>
    /// 二级审批时间
    /// </summary>
    [SugarColumn(ColumnDescription = "审批时间")]
    public DateTime? LevelTwoAuditTime { get; set; }

    /// <summary>
    /// 配置金额
    /// </summary>
    [SugarColumn(ColumnDescription = "配置金额")]
    public double ShouldAmount { get; set; }

    /// <summary>
    /// 审批金额
    /// </summary>
    [SugarColumn(ColumnDescription = "审批金额")]
    public double? ApprovedAmount { get; set; }

    /// <summary>
    /// 实发金额
    /// </summary>
    [SugarColumn(ColumnDescription = "实发金额")]
    public double? AcutalAmount { get; set; }

    /// <summary>
    /// 补充发放金额
    /// </summary>
    [SugarColumn(ColumnDescription = "补充发放金额")]
    public double? ReplenishAmount { get; set; }

    /// <summary>
    /// 补充发放时间
    /// </summary>
    [SugarColumn(ColumnDescription = "补充发放时间")]
    public DateTime? ReplenishTime { get; set; }

    /// <summary>
    /// 补充发放备注
    /// </summary>
    [SugarColumn(ColumnDescription = "补充发放备注")]
    public string? ReplenishRemark { get; set; }

    /// <summary>
    /// 补充发放类型
    /// </summary>
    [SugarColumn(ColumnDescription = "补充发放类型")]
    public string? ReplenishType { get; set; }

    /// <summary>
    /// 补充发放类型Id
    /// </summary>
    [SugarColumn(ColumnDescription = "补充发放类型Id")]
    public string? ReplenishTypeId { get; set; }

    /// <summary>
    /// 网格员奖励发放结果
    /// </summary>
    [SugarColumn(ColumnDescription = "网格员奖励发放结果")]
    public bool IsSend { get; set; }

    /// <summary>
    /// 网格员奖励发放备注
    /// </summary>
    [SugarColumn(ColumnDescription = "网格员奖励发放备注")]
    public string? SendRemarks { get; set; }

    /// <summary>
    /// 操作人
    /// </summary>
    [SugarColumn(ColumnDescription = "操作人")]
    public string? AuditId { get; set; }

    /// <summary>
    /// 操作人
    /// </summary>
    [SugarColumn(ColumnDescription = "操作人")]
    public string? AuditName { get; set; }

    /// <summary>
    /// 审批部门
    /// </summary>
    [SugarColumn(ColumnDescription = "审批部门")]
    public string? AuditOrgId { get; set; }

    /// <summary>
    /// 审批部门名称
    /// </summary>
    [SugarColumn(ColumnDescription = "审批部门名称")]
    public string? AuditOrgName { get; set; }

    /// <summary>
    /// 审批意见
    /// </summary>
    [SugarColumn(ColumnDescription = "审批意见")]
    public string? AuditRemark { get; set; }

    public string? Remark { get; set; }

    /// <summary>
    /// 是否已发放
    /// </summary>
    [SugarColumn(ColumnDescription = "是否已发放")]
    public bool? IsIssued { get; set; }

    /// <summary>
    /// 短信Id
    /// </summary>
    [SugarColumn(ColumnDescription = "短信Id")]
    public string? SMSTemplateId { get; set; }

    /// <summary>
    /// 是否发送短信
    /// </summary>
    [SugarColumn(ColumnDescription = "是否发送短信")]
    public bool? IsSendSMS { get; set; }
}
